@@ -15,22 +15,22 @@
 """Graphical support for Bazaar using GTK.
 
 This plugin includes:
-gannotate         GTK+ annotate. 
-gbranch           GTK+ branching. 
-gcheckout         GTK+ checkout. 
+gannotate         GTK+ annotate.
+gbranch           GTK+ branching.
+gcheckout         GTK+ checkout.
 gcommit           GTK+ commit dialog.
-gconflicts        GTK+ conflicts. 
-gdiff             Show differences in working tree in a GTK+ Window. 
+gconflicts        GTK+ conflicts.
+gdiff             Show differences in working tree in a GTK+ Window.
 ginit             Initialise a new branch.
 gloom             GTK+ loom browse dialog
 gmerge            GTK+ merge dialog
-gmissing          GTK+ missing revisions dialog. 
-gpreferences      GTK+ preferences dialog. 
+gmissing          GTK+ missing revisions dialog.
+gpreferences      GTK+ preferences dialog.
 gpush             GTK+ push.
 gsend             GTK+ send merge directive.
 gstatus           GTK+ status dialog.
 gtags             Manage branch tags.
-visualise         Graphically visualise this branch. 
+visualise         Graphically visualise this branch.
 """
 
 import os
@@ -58,8 +58,10 @@ from bzrlib import (
     )
 from bzrlib.commands import plugin_cmds
 
-
-version_info = (0, 99, 0, 'final', 0)
+from info import (
+    bzr_plugin_version as version_info,
+    bzr_compatible_versions,
+    )
 
 if version_info[3] == 'final':
     version_string = '%d.%d.%d' % version_info[:3]
@@ -67,15 +69,7 @@ else:
     version_string = '%d.%d.%d%s%d' % version_info
 __version__ = version_string
 
-COMPATIBLE_BZR_VERSIONS = [(1, 6, 0), (1, 7, 0), (1, 8, 0), (1, 9, 0),
-                           (1, 10, 0), (1, 11, 0), (1, 12, 0), (1, 13, 0),
-                           (1, 15, 0),
-                           (1, 17, 0),
-                           (2, 1, 0),
-                           (2, 2, 0),
-                           ]
-
-bzrlib.api.require_any_api(bzrlib, COMPATIBLE_BZR_VERSIONS)
+bzrlib.api.require_any_api(bzrlib, bzr_compatible_versions)
 
 if __name__ != 'bzrlib.plugins.gtk':
     from bzrlib.trace import warning
@@ -115,17 +109,6 @@ def icon_path(*args):
     return data_path(os.path.join('icons', *args))
 
 
-def open_display():
-    pygtk = import_pygtk()
-    try:
-        import gtk
-    except RuntimeError, e:
-        if str(e) == "could not open display":
-            raise NoDisplayError
-    set_ui_factory()
-    return gtk
-
-
 commands = {
     "gannotate": ["gblame", "gpraise"],
     "gbranch": [],
@@ -138,7 +121,6 @@ commands = {
     "gmissing": [],
     "gpreferences": [],
     "gpush": [],
-    "gselftest": [],
     "gsend": [],
     "gstatus": ["gst"],
     "gtags": [],
@@ -164,13 +146,6 @@ branch.Branch.hooks.install_named_hook('post_uncommit',
                                        save_commit_messages,
                                        "Saving commit messages for gcommit")
 
-class NoDisplayError(errors.BzrCommandError):
-    """gtk could not find a proper display"""
-
-    def __str__(self):
-        return "No DISPLAY. Unable to run GTK+ application."
-
-
 credential_store_registry = getattr(config, "credential_store_registry", None)
 if credential_store_registry is not None:
     try:
