@@ -6,21 +6,18 @@
 __copyright__ = "Copyright © 2005 Canonical Ltd."
 __author__    = "Daniel Schierbeck <daniel.schierbeck@gmail.com>"
 
-import sys
-import string
 import gtk
 import gobject
 import pango
-import re
 import treemodel
 from bzrlib import ui
 
-from bzrlib.plugins.gtk import _i18n
-from bzrlib.plugins.gtk.ui import GtkProgressBar, ProgressPanel
+from bzrlib.plugins.gtk.ui import ProgressPanel
 from linegraph import linegraph, same_branch
 from graphcell import CellRendererGraph
 from treemodel import TreeModel
 from bzrlib.revision import NULL_REVISION
+from bzrlib.plugins.gtk import lock
 
 
 class TreeView(gtk.VBox):
@@ -110,10 +107,11 @@ class TreeView(gtk.VBox):
         """
         gtk.VBox.__init__(self, spacing=0)
 
-        loading_msg_widget = ProgressPanel()
-        if getattr(ui.ui_factory, "set_nested_progress_bar_widget", None) is not None:
-            ui.ui_factory.set_nested_progress_bar_widget(loading_msg_widget.get_progress_bar)
-        self.pack_start(loading_msg_widget, expand=False, fill=True)
+        self.progress_widget = ProgressPanel()
+        self.pack_start(self.progress_widget, expand=False, fill=True)
+        if getattr(ui.ui_factory, "set_progress_bar_widget", None) is not None:
+            # We'are using our own ui, let's tell it to use our widget.
+            ui.ui_factory.set_progress_bar_widget(self.progress_widget)
 
         self.scrolled_window = gtk.ScrolledWindow()
         self.scrolled_window.set_policy(gtk.POLICY_AUTOMATIC,
@@ -124,7 +122,7 @@ class TreeView(gtk.VBox):
 
         self.scrolled_window.add(self.construct_treeview())
 
-        self.iter = None
+        self.path = None
         self.branch = branch
         self.revision = None
         self.index = {}
@@ -135,7 +133,13 @@ class TreeView(gtk.VBox):
 
         gobject.idle_add(self.populate)
 
-        self.connect("destroy", lambda x: self.branch.unlock())
+        self.connect("destroy", self._on_destroy)
+
+    def _on_destroy(self, *ignored):
+        self.branch.unlock()
+        if getattr(ui.ui_factory, "set_progress_bar_widget", None) is not None:
+            # We'are using our own ui, let's tell it to stop using our widget.
+            ui.ui_factory.set_progress_bar_widget(None)
 
     def do_get_property(self, property):
         if property.name == 'revno-column-visible':
@@ -151,13 +155,17 @@ class TreeView(gtk.VBox):
         elif property.name == 'branch':
             return self.branch
         elif property.name == 'revision':
-            return self.model.get_value(self.iter, treemodel.REVISION)
+            return self.model.get_value(self.model.get_iter(self.path),
+                                        treemodel.REVISION)
         elif property.name == 'revision-number':
-            return self.model.get_value(self.iter, treemodel.REVNO)
+            return self.model.get_value(self.model.get_iter(self.path),
+                                        treemodel.REVNO)
         elif property.name == 'children':
-            return self.model.get_value(self.iter, treemodel.CHILDREN)
+            return self.model.get_value(self.model.get_iter(self.path),
+                                        treemodel.CHILDREN)
         elif property.name == 'parents':
-            return self.model.get_value(self.iter, treemodel.PARENTS)
+            return self.model.get_value(self.model.get_iter(self.path),
+                                        treemodel.PARENTS)
         else:
             raise AttributeError, 'unknown property %s' % property.name
 
@@ -214,19 +222,16 @@ class TreeView(gtk.VBox):
     def add_tag(self, tag, revid=None):
         if revid is None: revid = self.revision.revision_id
 
-        try:
-            self.branch.unlock()
-
+        if lock.release(self.branch):
             try:
-                self.branch.lock_write()
+                lock.acquire(self.branch, lock.WRITE)
                 self.model.add_tag(tag, revid)
             finally:
-                self.branch.unlock()
+                lock.release(self.branch)
 
-        finally:
-            self.branch.lock_read()
+            lock.acquire(self.branch, lock.READ)
 
-        self.emit('tag-added', tag, revid)
+            self.emit('tag-added', tag, revid)
         
     def refresh(self):
         gobject.idle_add(self.populate, self.get_revision())
@@ -282,6 +287,9 @@ class TreeView(gtk.VBox):
                        should be broken.
         """
 
+        if getattr(ui.ui_factory, "set_progress_bar_widget", None) is not None:
+            # We'are using our own ui, let's tell it to use our widget.
+            ui.ui_factory.set_progress_bar_widget(self.progress_widget)
         self.progress_bar = ui.ui_factory.nested_progress_bar()
         self.progress_bar.update("Loading ancestry graph", 0, 5)
 
@@ -384,13 +392,13 @@ class TreeView(gtk.VBox):
         cell = gtk.CellRendererText()
         cell.set_property("width-chars", 15)
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
-        self.committer_column = gtk.TreeViewColumn("Committer")
-        self.committer_column.set_resizable(False)
-        self.committer_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
-        self.committer_column.set_fixed_width(200)
-        self.committer_column.pack_start(cell, expand=True)
-        self.committer_column.add_attribute(cell, "text", treemodel.COMMITTER)
-        self.treeview.append_column(self.committer_column)
+        self.authors_column = gtk.TreeViewColumn("Author(s)")
+        self.authors_column.set_resizable(False)
+        self.authors_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
+        self.authors_column.set_fixed_width(200)
+        self.authors_column.pack_start(cell, expand=True)
+        self.authors_column.add_attribute(cell, "text", treemodel.AUTHORS)
+        self.treeview.append_column(self.authors_column)
 
         cell = gtk.CellRendererText()
         cell.set_property("width-chars", 20)
@@ -411,7 +419,7 @@ class TreeView(gtk.VBox):
         (path, focus) = treeview.get_cursor()
         if (path is not None) and (path != self._prev_cursor_path):
             self._prev_cursor_path = path # avoid emitting twice per click
-            self.iter = self.model.get_iter(path)
+            self.path = path
             self.emit('revision-selected')
 
     def _on_revision_selected(self, widget, event):
